@@ -8,6 +8,7 @@ sentry_hipchat.models
 
 from django import forms
 
+from sentry.conf import settings
 from sentry.models import ProjectOption
 from sentry.plugins import Plugin, register
 
@@ -16,10 +17,20 @@ import urllib2
 import json
 import logging
 
+COLORS = dict(
+    ERROR = 'red',
+    WARNING = 'yellow',
+    INFO = 'green',
+    DEBUG = 'purple',
+)   
+
 
 class HipchatOptionsForm(forms.Form):
     token = forms.CharField(help_text="Your hipchat API token.")
     room = forms.CharField(help_text="Room name or ID.")
+    new_only = forms.BooleanField(help_text='Only send new messages.', required=False)
+    notify = forms.BooleanField(help_text='Notify message in chat window.', required=False)
+    include_project_name = forms.BooleanField(help_text='Include project name in message.', required=False)
 
 
 @register
@@ -35,20 +46,36 @@ class HipchatMessage(Plugin):
         return all((self.get_option(k, project) for k in ('room', 'token')))
 
     def post_process(self, group, event, is_new, is_sample, **kwargs):
+        new_only = self.get_option('new_only', event.project)
+        if new_only and not is_new:
+            return
+
         token = self.get_option('token', event.project)
         room = self.get_option('room', event.project)
-        if token and room:
-            self.send_payload(token, room, '[%s] %s' % (event.server_name, event.message))
+        notify = self.get_option('notify', event.project)
+        include_project_name = self.get_option('include_project_name', event.project)
+        level = event.get_level_display().upper()
+        link = '<a href="%s/%s/group/%d/">(link)</a>' % (settings.URL_PREFIX, group.project.slug, group.id)
 
-    def send_payload(self, token, room, message):
+        if token and room:
+            self.send_payload(token, room, '%(site)s[%(server)s]%(project_name)s %(message)s %(link)s' % {
+                'server': event.server_name,
+                'site': ('%s ' % event.site) if event.site else '',
+                'project_name': (' <strong>%s</strong>' % event.project.name) if include_project_name else '',
+                'message': event.message,
+                'link': link,
+                },
+                              notify, color=COLORS.get(level, 'purple'))
+
+    def send_payload(self, token, room, message, notify, color='red'):
         url = "https://api.hipchat.com/v1/rooms/message"
         values = {
             'auth_token': token,
             'room_id': room,
             'from': 'Sentry',
             'message': message,
-            'notify': False,
-            'color': 'red',
+            'notify': int(notify),
+            'color': color,
         }
         data = urllib.urlencode(values)
         request = urllib2.Request(url, data)
